@@ -260,7 +260,7 @@ console = Console(
             "markdown.link": "#6088ff",
             "wheel.distribution": "#92EC5A",
             "wheel.version": "#F2C259",
-            "wheel.build_tag": "#FFF075",
+            "wheel.build_tag": "#FF7F30",
             "wheel.python_tag": "#FF6EF8",
             "wheel.abi_tag": "#9263FB",
             "wheel.platform_tag": "#33F1C8",
@@ -606,22 +606,22 @@ def description(
 
 @app.command()
 def new_packages(
-    _author: bool = Option(False, metavar="author", help="Show the project author or not"),
-    _link: bool = Option(True, metavar="link", help="Show the project link or not"),
+    author: bool = Option(False, metavar="author", help="Show the project author or not"),
+    link: bool = Option(True, metavar="link", help="Show the project link or not"),
 ):
     """See the top 40 newly added packages."""
     _format_xml_packages(
-        f"{base_url}/rss/packages.xml", "Newly Added Packages", "Published At", _author, _link, split_title=True
+        f"{base_url}/rss/packages.xml", "Newly Added Packages", "Published At", author, link, split_title=True
     )
 
 
 @app.command()
 def new_releases(
-    _author: bool = Option(False, metavar="author", help="Show the project author or not"),
-    _link: bool = Option(True, metavar="link", help="Show the project link or not"),
+    author: bool = Option(False, metavar="author", help="Show the project author or not"),
+    link: bool = Option(True, metavar="link", help="Show the project link or not"),
 ):
     """See the top 100 newly updated packages."""
-    _format_xml_packages(f"{base_url}/rss/updates.xml", "Newly Released Packages", "Released At", _author, _link)
+    _format_xml_packages(f"{base_url}/rss/updates.xml", "Newly Released Packages", "Released At", author, link)
 
 
 @app.command()
@@ -725,7 +725,7 @@ def releases(
         "also include the version with this syntax: `package_name==version`",
     ),
     version: str = Option(None, help="The version of the package to show releases for"),
-    _link: bool = Option(False, metavar="link", help="Display the links to the releases"),
+    link: bool = Option(False, metavar="link", help="Display the links to the releases"),
 ):
     """See all the available releases for a package.
 
@@ -750,7 +750,7 @@ def releases(
     table.add_column("Version", style="green", header_style="green")
     table.add_column("Upload date", width=24, style="red", header_style="red")
     table.add_column("Size", style="yellow", header_style="yellow")
-    if _link is True:
+    if link is True:
         table.add_column("Link", style="cyan", header_style="blue")
 
     for version, releases in parsed_data["releases"].items():
@@ -763,7 +763,7 @@ def releases(
         except ValueError:
             upload_time = datetime.strptime(release["upload_time_iso_8601"], "%Y-%m-%dT%H:%M:%SZ")
 
-        if _link is True:
+        if link is True:
             table.add_row(
                 f"[link={release['url']}] {version}[/]",
                 upload_time.strftime("%c"),
@@ -911,9 +911,13 @@ def information(
     except ImportError:
         from distutils.version import LooseVersion as parse_version  # pylint:disable=import-outside-toplevel
 
+    from datetime import timezone  # pylint: disable=import-outside-toplevel
+
     if urls:
         # HACK: should use fromisotime
-        release_time = datetime.strptime(urls[-1]["upload_time_iso_8601"], "%Y-%m-%dT%H:%M:%S.%fZ")
+        release_time = utc_to_local(
+            datetime.strptime(urls[-1]["upload_time_iso_8601"], "%Y-%m-%dT%H:%M:%S.%fZ"), timezone.utc
+        )
         natural_time = release_time.strftime("%b %d, %Y")
     else:
         natural_time = "UNKNOWN"
@@ -1339,6 +1343,10 @@ def version(
         None, help="The name or link to the docs of the package to show the documentation for"
     ),
     limit: int = Option(10, help="Limit the number of versions to show"),
+    no_pre_releases: bool = Option(False, help="If set then it will not show pre-releases"),
+    minimal: bool = Option(
+        False, help="Whether to show minimal output, this is enabled if there are less than 3 versions to show"
+    ),
 ):
     """Show the cli's or another package's version and exit"""
     if not package_name:
@@ -1365,13 +1373,47 @@ def version(
     try:
         from packaging.version import parse as parse_version  # pylint:disable=import-outside-toplevel
     except ImportError:
+        if no_pre_releases:
+            rich.print(
+                "[red]:no_entry_sign: Install packaging (`pip install packaging`) to use the --no-pre-releases flag[/]"
+            )
+            raise typer.Exit()
         from distutils.version import LooseVersion as parse_version  # pylint:disable=import-outside-toplevel
 
-    latest_versions = list(sorted(map(parse_version, parsed_data["releases"].keys()), reverse=True))[:limit]
-    output = f"Top {limit} latest versions of [green]{package_name}[/] ordered by version number:\n"
+    if not no_pre_releases:
+        latest_versions = list(sorted(map(parse_version, parsed_data["releases"].keys()), reverse=True))[:limit]
+    else:
+        latest_versions = list(
+            sorted(
+                filter(lambda x: not x.is_prerelease, map(parse_version, parsed_data["releases"].keys())), reverse=True
+            )
+        )[:limit]
+    latest_versions_length = len(latest_versions)
+    if latest_versions_length <= 3:
+        minimal = True
+
+    if not minimal:
+        output = f"{f'Top {limit} latest versions of ' if limit > 1 else 'Latest version of '}[green]{package_name}[/]{' (excluding pre-releases)' if no_pre_releases else ''}:\n"
+    else:
+        output = f"[green]{package_name}[/]:"
+
+    from datetime import timezone  # pylint: disable=import-outside-toplevel
+
     for n, version in enumerate(latest_versions, start=1):
-        output += f" [magenta]{n}.[/] [white]{version}[/]\n"
-    console.print(output)
+        output += f" {f'[magenta]{n}.[/] ' if latest_versions_length > 1 else ''}[white]{version}[/]"
+        try:
+            upload_time = utc_to_local(
+                datetime.strptime(
+                    parsed_data["releases"][str(version)][0]["upload_time_iso_8601"], "%Y-%m-%dT%H:%M:%S.%fZ"
+                ),
+                timezone.utc,
+            )
+            output += f" [red]{humanize.naturaltime(upload_time)}[/] [cyan]({upload_time.strftime('%a %b %d %H:%M:%S %Y')})[/]"
+        except Exception as e:
+            print(e)
+        finally:
+            output += "\n"
+    console.print(output.strip())
 
 
 @app.callback()
